==> bea_flutter_package-0.76.129.tar.gz: lib/bea_services/core/bea_user_manager.dart <==
import 'dart:async';
import 'dart:convert';

import 'package:bea_flutter_package/bea_services/dtos/bea_models/base_models/error/bea_error.dart';
import 'package:bea_flutter_package/bea_services/dtos/bea_models/base_models/session/result_current_login_info.dart';
import 'package:bea_flutter_package/bea_services/dtos/bea_models/base_models/user/change_expired_password/bea_change_expired_password_input.dart';
import 'package:bea_flutter_package/bea_services/dtos/bea_models/base_models/user/change_password/bea_change_password_input.dart';
import 'package:bea_flutter_package/bea_services/dtos/bea_models/base_models/user/forget_password/bea_forget_password_input.dart';
import 'package:bea_flutter_package/bea_services/dtos/bea_models/base_models/user/get_bea_users/get_bea_users_input.dart';
import 'package:bea_flutter_package/bea_services/dtos/bea_models/base_models/user/get_bea_users/get_bea_users_output.dart';
import 'package:bea_flutter_package/bea_services/dtos/bea_models/base_models/user/request_forget_password/bea_request_forget_password_input.dart';
import 'package:bea_flutter_package/bea_services/dtos/bea_models/base_models/user/request_forget_password/bea_request_forget_password_output.dart';
import 'package:bea_flutter_package/bea_services/dtos/flutter_models/input/generic_server_input.dart';
import 'package:bea_flutter_package/bea_services/dtos/flutter_models/output/bea_session.dart';
import 'package:bea_flutter_package/bea_services/utils/url_utils.dart';
import 'package:f_logs/model/flog/flog.dart';
import 'package:flutter_secure_storage/flutter_secure_storage.dart';
import 'package:http/http.dart';

import '../dtos/flutter_models/output/generic_server_response.dart';
import 'bea_service_manager.dart';

class BeaUserManager{
  final BeaServiceManager bsm;

  String _baseUrl = "";
  FlutterSecureStorage storage;

  BeaUserManager(this.bsm){
    try{
      if(bsm == null){
        throw new Exception("${this.runtimeType.toString()} not initialized");
      }

      _baseUrl = bsm.getBaseUrl();
      storage = bsm.getBeaStorage();
    }on Exception catch (e){
      print('Initialization ${this.runtimeType.toString()} error');
      FLog.error(
          className: this.runtimeType.toString(),
          methodName: "Costructor",
          text: 'Initialization ${this.runtimeType.toString()} error - $e');
      throw e;
    }
  }

  Future<GenericServerResponse<BeaResultCurrentUserInfo>> getUserSessionInfo(GenericServerInput input) async {
    GenericServerResponse<BeaResultCurrentUserInfo> genericServerResponse = new GenericServerResponse<BeaResultCurrentUserInfo>();
    try{

      if(input == null){
        throw new Exception("Input not found.");
      }

      String url = UrlUtils.getUrl(_baseUrl, UrlUtils.URL_CURRENT_LOGIN_INFO);

      String jsonInput = '{}';

      Response response = await bsm.genericBeaHttpPost(url, jsonInput);
      int statusCode = response.statusCode;

      switch(statusCode){
        case 200:
          genericServerResponse.data = BeaResultCurrentUserInfo.fromJson(jsonDecode(response.body)['result']);
          break;
        case 500:
          BeaError error = BeaError.fromJson(jsonDecode(response.body)['error']);
          if (error != null) {
            genericServerResponse.beaError = error;
          } else {
            genericServerResponse.beaError = new BeaError("Unknown Error", 0, "");
          }
          break;
        case 401:
          genericServerResponse.beaSession = new BeaSession(true);
          break;
      }
    }on Exception catch (e){
      print('Error to get BEA user session info');
      FLog.error(
          className: this.runtimeType.toString(),
          methodName: "getUserSessionInfo",
          text: 'Error to get BEA user session info - $e');
      throw e;
    }

    return genericServerResponse;
  }

  Future<GenericServerResponse<BeaRequestForgerPasswordOutput>> requestForgetPassword(GenericServerInput<BeaRequestForgerPasswordInput> input) async {
    GenericServerResponse<BeaRequestForgerPasswordOutput> genericServerResponse =
      new GenericServerResponse<BeaRequestForgerPasswordOutput>();
    try{

      if(input == null){
        throw new Exception("Input not found.");
      }

      String url = UrlUtils.getUrl(_baseUrl, UrlUtils.URL_REQUEST_FORGET_PASSWORD);

      String jsonInput = jsonEncode(input.input.toJson());

      Response response = await bsm.genericBeaHttpPost(url, jsonInput);
      int statusCode = response.statusCode;

      switch(statusCode){
        case 200:
          genericServerResponse.data = BeaRequestForgerPasswordOutput.fromJson(jsonDecode(response.body)['result']);
          break;
        case 500:
          BeaError error = BeaError.fromJson(jsonDecode(response.body)['error']);
          if (error != null) {
            genericServerResponse.beaError = error;
          } else {
            genericServerResponse.beaError = new BeaError("Unknown Error", 0, "");
          }
          break;
        case 401:
          genericServerResponse.beaSession = new BeaSession(true);
          break;
      }
    }on Exception catch (e){
      print('Error request BEA forget password');
      FLog.error(
          className: this.runtimeType.toString(),
          methodName: "requestForgetPassword",
          text: 'Error request BEA forget password - $e');
      throw e;
    }

    return genericServerResponse;
  }

  Future<GenericServerResponse> forgetPassword(GenericServerInput<BeaForgerPasswordInput> input) async {
    GenericServerResponse genericServerResponse = new GenericServerResponse();
    try{

      if(input == null){
        throw new Exception("Input not found.");
      }

      String url = UrlUtils.getUrl(_baseUrl, UrlUtils.URL_FORGET_PASSWORD);

      String jsonInput = jsonEncode(input.input.toJson());

      Response response = await bsm.genericBeaHttpPost(url, jsonInput);
      int statusCode = response.statusCode;

      switch(statusCode){
        case 200:
          genericServerResponse.data = "OK";
          break;
        case 500:
          BeaError error = BeaError.fromJson(jsonDecode(response.body)['error']);
          if (error != null) {
            genericServerResponse.beaError = error;
          } else {
            genericServerResponse.beaError = new BeaError("Unknown Error", 0, "");
          }
          break;
        case 401:
          genericServerResponse.beaSession = new BeaSession(true);
          break;
      }
    }on Exception catch (e){
      print('Error forget BEA Password');
      FLog.error(
          className: this.runtimeType.toString(),
          methodName: "forgetPassword",
          text: 'Error forget BEA Password - $e');
      throw e;
    }

    return genericServerResponse;
  }

  Future<GenericServerResponse> changePassword(GenericServerInput<BeaChangePasswordInput> input) async {
    GenericServerResponse genericServerResponse = new GenericServerResponse();
    try{

      if(input == null){
        throw new Exception("Input not found.");
      }

      String url = UrlUtils.getUrl(_baseUrl, UrlUtils.URL_CHANGE_PASSWORD);

      String jsonInput = jsonEncode(input.input.toJson());

      Response response = await bsm.genericBeaHttpPost(url, jsonInput);
      int statusCode = response.statusCode;

      switch(statusCode){
        case 200:
          genericServerResponse.data = "OK";
          break;
        case 500:
          BeaError error = BeaError.fromJson(jsonDecode(response.body)['error']);
          if (error != null) {
            genericServerResponse.beaError = error;
          } else {
            genericServerResponse.beaError = new BeaError("Unknown Error", 0, "");
          }
          break;
        case 401:
          genericServerResponse.beaSession = new BeaSession(true);
          break;
      }
    }on Exception catch (e){
      print('Error change BEA Password');
      FLog.error(
          className: this.runtimeType.toString(),
          methodName: "changePassword",
          text: 'Error change BEA Password - $e');
      throw e;
    }

    return genericServerResponse;
  }

  Future<GenericServerResponse> changeExpiredPassword(GenericServerInput<BeaChangeExpiredPasswordInput> input) async {
    GenericServerResponse genericServerResponse = new GenericServerResponse();
    try{

      if(input == null){
        throw new Exception("Input not found.");
      }

      String url = UrlUtils.getUrl(_baseUrl, UrlUtils.URL_CHANGE_EXPIRED_PASSWORD);

      String jsonInput = jsonEncode(input.input.toJson());

      Response response = await bsm.genericBeaHttpPost(url, jsonInput);
      int statusCode = response.statusCode;

      switch(statusCode){
        case 200:
          genericServerResponse.data = "OK";
          break;
        case 500:
          BeaError error = BeaError.fromJson(jsonDecode(response.body)['error']);
          if (error != null) {
            genericServerResponse.beaError = error;
          } else {
            genericServerResponse.beaError = new BeaError("Unknown Error", 0, "");
          }
          break;
        case 401:
          genericServerResponse.beaSession = new BeaSession(true);
          break;
      }
    }on Exception catch (e){
      print('Error change expired BEA Password');
      FLog.error(
          className: this.runtimeType.toString(),
          methodName: "changeExpiredPassword",
          text: 'Error change expired BEA Password - $e');
      throw e;
    }

    return genericServerResponse;
  }

  Future<GenericServerResponse<GetBeaUsersOutput>> getUsers(GenericServerInput<GetBeaUsersInput> input) async {
    GenericServerResponse<GetBeaUsersOutput> genericServerResponse = new GenericServerResponse<GetBeaUsersOutput>();
    try{

      String url = UrlUtils.getUrl(_baseUrl, UrlUtils.URL_GET_ALL_USERS);

      String jsonInput = "{}";

      Response response = await bsm.genericBeaHttpPost(url, jsonInput);
      int statusCode = response.statusCode;

      switch(statusCode){
        case 200:
          genericServerResponse.data = GetBeaUsersOutput.fromJson(jsonDecode(response.body)['result']);
          break;
        case 500:
          BeaError error = BeaError.fromJson(jsonDecode(response.body)['error']);
          if (error != null) {
            genericServerResponse.beaError = error;
          } else {
            genericServerResponse.beaError = new BeaError("Unknown Error", 0, "");
          }
          break;
        case 401:
          genericServerResponse.beaSession = new BeaSession(true);
          break;
      }
    }on Exception catch (e){
      print('Error getUsers');
      FLog.error(
          className: this.runtimeType.toString(),
          methodName: "getUsers",
          text: 'Error getUsers - $e');
      throw e;
    }

    return genericServerResponse;
  }
}

==> bea_flutter_package-1.1.1.tar.gz: lib/bea_services/core/bea_user_manager.dart <==
import 'dart:async';
import 'dart:convert';

import 'package:bea_flutter_package/bea_services/dtos/bea_models/base_models/error/bea_error.dart';
import 'package:bea_flutter_package/bea_services/dtos/bea_models/base_models/session/result_current_login_info.dart';
import 'package:bea_flutter_package/bea_services/dtos/bea_models/base_models/user/change_expired_password/bea_change_expired_password_input.dart';
import 'package:bea_flutter_package/bea_services/dtos/bea_models/base_models/user/change_password/bea_change_password_input.dart';
import 'package:bea_flutter_package/bea_services/dtos/bea_models/base_models/user/forget_password/bea_forget_password_input.dart';
import 'package:bea_flutter_package/bea_services/dtos/bea_models/base_models/user/get_bea_users/get_bea_users_input.dart';
import 'package:bea_flutter_package/bea_services/dtos/bea_models/base_models/user/get_bea_users/get_bea_users_output.dart';
import 'package:bea_flutter_package/bea_services/dtos/bea_models/base_models/user/request_forget_password/bea_request_forget_password_input.dart';
import 'package:bea_flutter_package/bea_services/dtos/bea_models/base_models/user/request_forget_password/bea_request_forget_password_output.dart';
import 'package:bea_flutter_package/bea_services/dtos/flutter_models/input/generic_server_input.dart';
import 'package:bea_flutter_package/bea_services/dtos/flutter_models/output/bea_session.dart';
import 'package:bea_flutter_package/bea_services/utils/url_utils.dart';
import 'package:dio/dio.dart';
import 'package:f_logs/model/flog/flog.dart';
import 'package:flutter_secure_storage/flutter_secure_storage.dart';

import '../dtos/flutter_models/output/generic_server_response.dart';
import 'bea_service_manager.dart';

class BeaUserManager{
  final BeaServiceManager bsm;

  String _baseUrl = "";
  FlutterSecureStorage storage;

  BeaUserManager(this.bsm){
    try{
      if(bsm == null){
        throw new Exception("${this.runtimeType.toString()} not initialized");
      }

      _baseUrl = bsm.getBaseUrl();
      storage = bsm.getBeaStorage();
    }on Exception catch (e){
      print('Initialization ${this.runtimeType.toString()} error');
      FLog.error(
          className: this.runtimeType.toString(),
          methodName: "Costructor",
          text: 'Initialization ${this.runtimeType.toString()} error - $e');
      throw e;
    }
  }

  Future<GenericServerResponse<BeaResultCurrentUserInfo>> getUserSessionInfo(GenericServerInput input) async {
    GenericServerResponse<BeaResultCurrentUserInfo> genericServerResponse = new GenericServerResponse<BeaResultCurrentUserInfo>();
    try{

      if(input == null){
        throw new Exception("Input not found.");
      }

      String url = UrlUtils.getUrl(_baseUrl, UrlUtils.URL_CURRENT_LOGIN_INFO);

      String jsonInput = '{}';

      Response response = await bsm.genericBeaHttpPost(url, jsonInput);
      int statusCode = response.statusCode;

      switch(statusCode){
        case 200:
          genericServerResponse.data = BeaResultCurrentUserInfo.fromJson(jsonDecode(response.data)['result']);
          break;
        case 500:
          BeaError error = BeaError.fromJson(jsonDecode(response.data)['error']);
          if (error != null) {
            genericServerResponse.beaError = error;
          } else {
            genericServerResponse.beaError = new BeaError("Unknown Error", 0, "");
          }
          break;
        case 401:
          genericServerResponse.beaSession = new BeaSession(true);
          break;
      }
    }on Exception catch (e){
      print('Error to get BEA user session info');
      FLog.error(
          className: this.runtimeType.toString(),
          methodName: "getUserSessionInfo",
          text: 'Error to get BEA user session info - $e');
      throw e;
    }

    return genericServerResponse;
  }

  Future<GenericServerResponse<BeaRequestForgerPasswordOutput>> requestForgetPassword(GenericServerInput<BeaRequestForgerPasswordInput> input) async {
    GenericServerResponse<BeaRequestForgerPasswordOutput> genericServerResponse =
      new GenericServerResponse<BeaRequestForgerPasswordOutput>();
    try{

      if(input == null){
        throw new Exception("Input not found.");
      }

      String url = UrlUtils.getUrl(_baseUrl, UrlUtils.URL_REQUEST_FORGET_PASSWORD);

      String jsonInput = jsonEncode(input.input.toJson());

      Response response = await bsm.genericBeaHttpPost(url, jsonInput);
      int statusCode = response.statusCode;

      switch(statusCode){
        case 200:
          genericServerResponse.data = BeaRequestForgerPasswordOutput.fromJson(jsonDecode(response.data)['result']);
          break;
        case 500:
          BeaError error = BeaError.fromJson(jsonDecode(response.data)['error']);
          if (error != null) {
            genericServerResponse.beaError = error;
          } else {
            genericServerResponse.beaError = new BeaError("Unknown Error", 0, "");
          }
          break;
        case 401:
          genericServerResponse.beaSession = new BeaSession(true);
          break;
      }
    }on Exception catch (e){
      print('Error request BEA forget password');
      FLog.error(
          className: this.runtimeType.toString(),
          methodName: "requestForgetPassword",
          text: 'Error request BEA forget password - $e');
      throw e;
    }

    return genericServerResponse;
  }

  Future<GenericServerResponse> forgetPassword(GenericServerInput<BeaForgerPasswordInput> input) async {
    GenericServerResponse genericServerResponse = new GenericServerResponse();
    try{

      if(input == null){
        throw new Exception("Input not found.");
      }

      String url = UrlUtils.getUrl(_baseUrl, UrlUtils.URL_FORGET_PASSWORD);

      String jsonInput = jsonEncode(input.input.toJson());

      Response response = await bsm.genericBeaHttpPost(url, jsonInput);
      int statusCode = response.statusCode;

      switch(statusCode){
        case 200:
          genericServerResponse.data = "OK";
          break;
        case 500:
          BeaError error = BeaError.fromJson(jsonDecode(response.data)['error']);
          if (error != null) {
            genericServerResponse.beaError = error;
          } else {
            genericServerResponse.beaError = new BeaError("Unknown Error", 0, "");
          }
          break;
        case 401:
          genericServerResponse.beaSession = new BeaSession(true);
          break;
      }
    }on Exception catch (e){
      print('Error forget BEA Password');
      FLog.error(
          className: this.runtimeType.toString(),
          methodName: "forgetPassword",
          text: 'Error forget BEA Password - $e');
      throw e;
    }

    return genericServerResponse;
  }

  Future<GenericServerResponse> changePassword(GenericServerInput<BeaChangePasswordInput> input) async {
    GenericServerResponse genericServerResponse = new GenericServerResponse();
    try{

      if(input == null){
        throw new Exception("Input not found.");
      }

      String url = UrlUtils.getUrl(_baseUrl, UrlUtils.URL_CHANGE_PASSWORD);

      String jsonInput = jsonEncode(input.input.toJson());

      Response response = await bsm.genericBeaHttpPost(url, jsonInput);
      int statusCode = response.statusCode;

      switch(statusCode){
        case 200:
          genericServerResponse.data = "OK";
          break;
        case 500:
          BeaError error = BeaError.fromJson(jsonDecode(response.data)['error']);
          if (error != null) {
            genericServerResponse.beaError = error;
          } else {
            genericServerResponse.beaError = new BeaError("Unknown Error", 0, "");
          }
          break;
        case 401:
          genericServerResponse.beaSession = new BeaSession(true);
          break;
      }
    }on Exception catch (e){
      print('Error change BEA Password');
      FLog.error(
          className: this.runtimeType.toString(),
          methodName: "changePassword",
          text: 'Error change BEA Password - $e');
      throw e;
    }

    return genericServerResponse;
  }

  Future<GenericServerResponse> changeExpiredPassword(GenericServerInput<BeaChangeExpiredPasswordInput> input) async {
    GenericServerResponse genericServerResponse = new GenericServerResponse();
    try{

      if(input == null){
        throw new Exception("Input not found.");
      }

      String url = UrlUtils.getUrl(_baseUrl, UrlUtils.URL_CHANGE_EXPIRED_PASSWORD);

      String jsonInput = jsonEncode(input.input.toJson());

      Response response = await bsm.genericBeaHttpPost(url, jsonInput);
      int statusCode = response.statusCode;

      switch(statusCode){
        case 200:
          genericServerResponse.data = "OK";
          break;
        case 500:
          BeaError error = BeaError.fromJson(jsonDecode(response.data)['error']);
          if (error != null) {
            genericServerResponse.beaError = error;
          } else {
            genericServerResponse.beaError = new BeaError("Unknown Error", 0, "");
          }
          break;
        case 401:
          genericServerResponse.beaSession = new BeaSession(true);
          break;
      }
    }on Exception catch (e){
      print('Error change expired BEA Password');
      FLog.error(
          className: this.runtimeType.toString(),
          methodName: "changeExpiredPassword",
          text: 'Error change expired BEA Password - $e');
      throw e;
    }

    return genericServerResponse;
  }

  Future<GenericServerResponse<GetBeaUsersOutput>> getUsers(GenericServerInput<GetBeaUsersInput> input) async {
    GenericServerResponse<GetBeaUsersOutput> genericServerResponse = new GenericServerResponse<GetBeaUsersOutput>();
    try{

      String url = UrlUtils.getUrl(_baseUrl, UrlUtils.URL_GET_ALL_USERS);

      String jsonInput = "{}";

      Response response = await bsm.genericBeaHttpPost(url, jsonInput);
      int statusCode = response.statusCode;

      switch(statusCode){
        case 200:
          genericServerResponse.data = GetBeaUsersOutput.fromJson(jsonDecode(response.data)['result']);
          break;
        case 500:
          BeaError error = BeaError.fromJson(jsonDecode(response.data)['error']);
          if (error != null) {
            genericServerResponse.beaError = error;
          } else {
            genericServerResponse.beaError = new BeaError("Unknown Error", 0, "");
          }
          break;
        case 401:
          genericServerResponse.beaSession = new BeaSession(true);
          break;
      }
    }on Exception catch (e){
      print('Error getUsers');
      FLog.error(
          className: this.runtimeType.toString(),
          methodName: "getUsers",
          text: 'Error getUsers - $e');
      throw e;
    }

    return genericServerResponse;
  }
}
